<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Information</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Oversættere</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1-browser til SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Mobil udgave</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Kompileret ved brug af Qt %1 (med %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Besøg vores websted for opdateringer:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Mange mennesker har bidraget med oversættelser.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Du kan også hjælpe med at oversætte SMTube til dit eget sprog.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Besøg %1 og meld dig til et oversættelsesteam.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Klik her for at se oversætterne fra Transifex-teams</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="125"/>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="128"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="136"/>
        <source>Zoom +</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="140"/>
        <source>Zoom -</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="144"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="159"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>Toolbar</source>
        <translation>Værktøjslinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="164"/>
        <source>Statusbar</source>
        <translation>Statuslinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="168"/>
        <source>&amp;Settings</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="179"/>
        <source>&amp;Update the YouTube code</source>
        <translation>Opdater &amp;YouTube-koden</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="185"/>
        <source>About this &amp;release</source>
        <translation>Om denne &amp;udgivelse</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="190"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;Om SMTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="298"/>
        <source>Download video using an external service</source>
        <translation>Download video ved brug af en ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="299"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="527"/>
        <source>Connection failed</source>
        <translation>Forbindelse mislykkedes</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="528"/>
        <source>The video you requested needs to open a HTTPS connection.</source>
        <translation>Videoen du har anmodet om har brug for at åbne en HTTPS-forbindelse.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="529"/>
        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
        <translation>Desværre er OpenSSL-komponenten, der kræves, ikke tilgængelige på dit system.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="534"/>
        <source>No video found</source>
        <translation>Der blev ikke fundet nogen video</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="535"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Det var ikke muligt at finde videoens URL.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="545"/>
        <location filename="../browserwindow.cpp" line="553"/>
        <source>Problems with YouTube</source>
        <translation>Problemer med YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="546"/>
        <location filename="../browserwindow.cpp" line="554"/>
        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
        <translation>Videoen &quot;%1&quot; kan desværre ikke afspilles, på grund af ændringer på YouTube.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="547"/>
        <source>Do you want to update the YouTube code? This may fix the problem.</source>
        <translation>Vil du opdatere YouTube-koden? Det vil måske rette problemet.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="555"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Opdatering af dette program kan muligvis rette problemet.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="574"/>
        <source>About this release</source>
        <translation>Om denne udgivelse</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="575"/>
        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
        <translation>Den gamle SMTube virker ikke længere, på grund af ændringer på YouTube.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="576"/>
        <source>This is a new version of SMTube, written from scratch.</source>
        <translation>Dette er en ny version af SMTube, skrevet fra bunden.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="577"/>
        <source>Some functionality is not available yet.</source>
        <translation>Nogle funktioner er endnu ikke tilgængelige.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>Important:</source>
        <translation>Vigtigt:</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="580"/>
        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
        <translation>Hvis VEVO-videoer ikke kan afspille, så brug venligst %1 i Hjælp-menuen.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="581"/>
        <source>Update the YouTube code</source>
        <translation>Opdater YouTube-koden</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="284"/>
        <source>Loading... %1%</source>
        <translation>Indlæser... %1%</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Generelt</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="108"/>
        <source>&amp;Players</source>
        <translation>&amp;Afspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="156"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="121"/>
        <source>Up</source>
        <translation>Op</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Afspilning</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="167"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="204"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Tilføj foruddefinerede afspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="240"/>
        <source>&amp;Interface</source>
        <translation>&amp;Grænseflade</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="248"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stil:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="284"/>
        <source>Font:</source>
        <translation>Skrifttype:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>C&amp;hange...</source>
        <translation>&amp;Vælg...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Download video ved brug af en &amp;ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="132"/>
        <source>Down</source>
        <translation>Ned</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Klik for at vælge en fil eller mappe</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Åbn i &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Gem link...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Kopiér &amp;link til udklipsholder</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Åbn link i dette vindue</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Kopiér tekst til udklipsholder</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Åbn link i &amp;nyt vindue</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Afspil med</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Afspil &amp;lyd med</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>&amp;Afspil med %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>Afspil &amp;lyd med %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Afspil video med en &amp;webbrowser</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Rediger afspiller</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Navn:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Programfil:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametre:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Denne afspiller understøtter &amp;video-steder</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Denne afspiller kan afspille &amp;online-TV</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Føj til &amp;menu:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video og lyd</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
</TS>
